@@ -1,5 +1,5 @@
 package Git::Raw::Index;
-$Git::Raw::Index::VERSION = '0.67';
+$Git::Raw::Index::VERSION = '0.68';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Git::Raw::Index - Git index class
 
 =head1 VERSION
 
-version 0.67
+version 0.68
 
 =head1 DESCRIPTION
 
@@ -38,7 +38,8 @@ or alternatively a L<Git::Raw::Index::Entry>.
 =head2 add_frombuffer( $path, $buffer )
 
 Add or update an entry from an in memory file. The entry will be placed at C<$path>
-with the contents of C<$buffer>.
+with the contents of C<$buffer>. C<$buffer> may either be string or a reference
+to a string.
 
 =head2 add_all( \%opts )
 
